@@ -9,11 +9,11 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.MediaTailor 1.20.1\n"
-        "Version:         1.20.1\n"
-        "Builder version: 6.1.2\n"
+        "Type annotations for boto3.MediaTailor 1.20.35\n"
+        "Version:         1.20.35.post1\n"
+        "Builder version: 6.3.2\n"
         "Docs:            https://pypi.org/project/mypy-boto3-mediatailor/\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
         "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
     )
@@ -23,7 +23,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.20.1")
+    print("1.20.35.post1")
 
 
 def main() -> None:
