@@ -95,7 +95,7 @@ class Exceptions:
 
 class MediaTailorClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html)
     """
 
@@ -111,7 +111,7 @@ class MediaTailorClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#can_paginate)
         """
 
@@ -121,7 +121,7 @@ class MediaTailorClient(BaseClient):
         """
         Configures Amazon CloudWatch log settings for a playback configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.configure_logs_for_playback_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.configure_logs_for_playback_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#configure_logs_for_playback_configuration)
         """
 
@@ -137,7 +137,7 @@ class MediaTailorClient(BaseClient):
         """
         Creates a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.create_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.create_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#create_channel)
         """
 
@@ -153,7 +153,7 @@ class MediaTailorClient(BaseClient):
         """
         Creates a new prefetch schedule for the specified playback configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.create_prefetch_schedule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.create_prefetch_schedule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#create_prefetch_schedule)
         """
 
@@ -170,7 +170,7 @@ class MediaTailorClient(BaseClient):
         """
         Creates a program.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.create_program)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.create_program)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#create_program)
         """
 
@@ -186,7 +186,7 @@ class MediaTailorClient(BaseClient):
         """
         Creates a source location on a specific channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.create_source_location)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.create_source_location)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#create_source_location)
         """
 
@@ -201,7 +201,7 @@ class MediaTailorClient(BaseClient):
         """
         Creates name for a specific VOD source in a source location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.create_vod_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.create_vod_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#create_vod_source)
         """
 
@@ -209,7 +209,7 @@ class MediaTailorClient(BaseClient):
         """
         Deletes a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.delete_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.delete_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#delete_channel)
         """
 
@@ -217,7 +217,7 @@ class MediaTailorClient(BaseClient):
         """
         Deletes a channel's IAM policy.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.delete_channel_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.delete_channel_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#delete_channel_policy)
         """
 
@@ -225,7 +225,7 @@ class MediaTailorClient(BaseClient):
         """
         Deletes the playback configuration for the specified name.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.delete_playback_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.delete_playback_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#delete_playback_configuration)
         """
 
@@ -235,7 +235,7 @@ class MediaTailorClient(BaseClient):
         """
         Deletes a prefetch schedule for a specific playback configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.delete_prefetch_schedule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.delete_prefetch_schedule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#delete_prefetch_schedule)
         """
 
@@ -243,7 +243,7 @@ class MediaTailorClient(BaseClient):
         """
         Deletes a specific program on a specific channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.delete_program)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.delete_program)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#delete_program)
         """
 
@@ -251,7 +251,7 @@ class MediaTailorClient(BaseClient):
         """
         Deletes a source location on a specific channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.delete_source_location)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.delete_source_location)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#delete_source_location)
         """
 
@@ -259,7 +259,7 @@ class MediaTailorClient(BaseClient):
         """
         Deletes a specific VOD source in a specific source location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.delete_vod_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.delete_vod_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#delete_vod_source)
         """
 
@@ -267,7 +267,7 @@ class MediaTailorClient(BaseClient):
         """
         Describes the properties of a specific channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.describe_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.describe_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#describe_channel)
         """
 
@@ -277,7 +277,7 @@ class MediaTailorClient(BaseClient):
         """
         Retrieves the properties of the requested program.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.describe_program)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.describe_program)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#describe_program)
         """
 
@@ -287,7 +287,7 @@ class MediaTailorClient(BaseClient):
         """
         Retrieves the properties of the requested source location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.describe_source_location)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.describe_source_location)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#describe_source_location)
         """
 
@@ -297,7 +297,7 @@ class MediaTailorClient(BaseClient):
         """
         Provides details about a specific VOD source in a specific source location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.describe_vod_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.describe_vod_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#describe_vod_source)
         """
 
@@ -311,7 +311,7 @@ class MediaTailorClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#generate_presigned_url)
         """
 
@@ -319,7 +319,7 @@ class MediaTailorClient(BaseClient):
         """
         Retrieves information about a channel's IAM policy.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.get_channel_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.get_channel_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#get_channel_policy)
         """
 
@@ -334,7 +334,7 @@ class MediaTailorClient(BaseClient):
         """
         Retrieves information about your channel's schedule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.get_channel_schedule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.get_channel_schedule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#get_channel_schedule)
         """
 
@@ -342,7 +342,7 @@ class MediaTailorClient(BaseClient):
         """
         Returns the playback configuration for the specified name.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.get_playback_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.get_playback_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#get_playback_configuration)
         """
 
@@ -353,7 +353,7 @@ class MediaTailorClient(BaseClient):
         Returns information about the prefetch schedule for a specific playback
         configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.get_prefetch_schedule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.get_prefetch_schedule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#get_prefetch_schedule)
         """
 
@@ -363,7 +363,7 @@ class MediaTailorClient(BaseClient):
         """
         Returns a list of alerts for the given resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.list_alerts)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.list_alerts)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#list_alerts)
         """
 
@@ -373,7 +373,7 @@ class MediaTailorClient(BaseClient):
         """
         Retrieves a list of channels that are associated with this account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.list_channels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.list_channels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#list_channels)
         """
 
@@ -384,7 +384,7 @@ class MediaTailorClient(BaseClient):
         Returns a list of the playback configurations defined in AWS Elemental
         MediaTailor.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.list_playback_configurations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.list_playback_configurations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#list_playback_configurations)
         """
 
@@ -399,7 +399,7 @@ class MediaTailorClient(BaseClient):
         """
         Creates a new prefetch schedule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.list_prefetch_schedules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.list_prefetch_schedules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#list_prefetch_schedules)
         """
 
@@ -409,7 +409,7 @@ class MediaTailorClient(BaseClient):
         """
         Retrieves a list of source locations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.list_source_locations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.list_source_locations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#list_source_locations)
         """
 
@@ -418,7 +418,7 @@ class MediaTailorClient(BaseClient):
         Returns a list of the tags assigned to the specified playback configuration
         resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#list_tags_for_resource)
         """
 
@@ -428,7 +428,7 @@ class MediaTailorClient(BaseClient):
         """
         Lists all the VOD sources in a source location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.list_vod_sources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.list_vod_sources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#list_vod_sources)
         """
 
@@ -436,7 +436,7 @@ class MediaTailorClient(BaseClient):
         """
         Creates an IAM policy for the channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.put_channel_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.put_channel_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#put_channel_policy)
         """
 
@@ -461,7 +461,7 @@ class MediaTailorClient(BaseClient):
         """
         Adds a new playback configuration to AWS Elemental MediaTailor.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.put_playback_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.put_playback_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#put_playback_configuration)
         """
 
@@ -469,7 +469,7 @@ class MediaTailorClient(BaseClient):
         """
         Starts a specific channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.start_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.start_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#start_channel)
         """
 
@@ -477,7 +477,7 @@ class MediaTailorClient(BaseClient):
         """
         Stops a specific channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.stop_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.stop_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#stop_channel)
         """
 
@@ -485,7 +485,7 @@ class MediaTailorClient(BaseClient):
         """
         Adds tags to the specified playback configuration resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#tag_resource)
         """
 
@@ -493,17 +493,21 @@ class MediaTailorClient(BaseClient):
         """
         Removes tags from the specified playback configuration resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#untag_resource)
         """
 
     def update_channel(
-        self, *, ChannelName: str, Outputs: Sequence["RequestOutputItemTypeDef"]
+        self,
+        *,
+        ChannelName: str,
+        Outputs: Sequence["RequestOutputItemTypeDef"],
+        FillerSlate: "SlateSourceTypeDef" = ...
     ) -> UpdateChannelResponseTypeDef:
         """
         Updates an existing channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.update_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.update_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#update_channel)
         """
 
@@ -518,7 +522,7 @@ class MediaTailorClient(BaseClient):
         """
         Updates a source location on a specific channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.update_source_location)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.update_source_location)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#update_source_location)
         """
 
@@ -532,7 +536,7 @@ class MediaTailorClient(BaseClient):
         """
         Updates a specific VOD source in a specific source location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Client.update_vod_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Client.update_vod_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/client.html#update_vod_source)
         """
 
@@ -541,21 +545,21 @@ class MediaTailorClient(BaseClient):
         self, operation_name: Literal["get_channel_schedule"]
     ) -> GetChannelSchedulePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Paginator.GetChannelSchedule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Paginator.GetChannelSchedule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#getchannelschedulepaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_alerts"]) -> ListAlertsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Paginator.ListAlerts)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Paginator.ListAlerts)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listalertspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_channels"]) -> ListChannelsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Paginator.ListChannels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Paginator.ListChannels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listchannelspaginator)
         """
 
@@ -564,7 +568,7 @@ class MediaTailorClient(BaseClient):
         self, operation_name: Literal["list_playback_configurations"]
     ) -> ListPlaybackConfigurationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Paginator.ListPlaybackConfigurations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listplaybackconfigurationspaginator)
         """
 
@@ -573,7 +577,7 @@ class MediaTailorClient(BaseClient):
         self, operation_name: Literal["list_prefetch_schedules"]
     ) -> ListPrefetchSchedulesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Paginator.ListPrefetchSchedules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Paginator.ListPrefetchSchedules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listprefetchschedulespaginator)
         """
 
@@ -582,13 +586,13 @@ class MediaTailorClient(BaseClient):
         self, operation_name: Literal["list_source_locations"]
     ) -> ListSourceLocationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Paginator.ListSourceLocations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Paginator.ListSourceLocations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listsourcelocationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_vod_sources"]) -> ListVodSourcesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/mediatailor.html#MediaTailor.Paginator.ListVodSources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.35/reference/services/mediatailor.html#MediaTailor.Paginator.ListVodSources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediatailor/paginators.html#listvodsourcespaginator)
         """
