@@ -1318,13 +1318,27 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-UpdateChannelRequestRequestTypeDef = TypedDict(
-    "UpdateChannelRequestRequestTypeDef",
+_RequiredUpdateChannelRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateChannelRequestRequestTypeDef",
     {
         "ChannelName": str,
         "Outputs": Sequence["RequestOutputItemTypeDef"],
     },
 )
+_OptionalUpdateChannelRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateChannelRequestRequestTypeDef",
+    {
+        "FillerSlate": "SlateSourceTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdateChannelRequestRequestTypeDef(
+    _RequiredUpdateChannelRequestRequestTypeDef, _OptionalUpdateChannelRequestRequestTypeDef
+):
+    pass
+
 
 UpdateChannelResponseTypeDef = TypedDict(
     "UpdateChannelResponseTypeDef",
